Index: typo3/jsfunc.tbe_editor.js
===================================================================
--- typo3/jsfunc.tbe_editor.js (revision 6707)
+++ typo3/jsfunc.tbe_editor.js (working copy)
@@ -1,4 +1,10 @@
/***************************************************************
+* ! DEPRECATED !
+* This file will be removed in TYPO3 4.6
+* This file is now located in typo3/js/
+****************************************************************/
+
+/***************************************************************
* Copyright notice
*
* (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
Index: typo3/md5.js
===================================================================
--- typo3/md5.js (revision 6707)
+++ typo3/md5.js (working copy)
@@ -1,3 +1,9 @@
+/***************************************************************
+* ! DEPRECATED !
+* This file will be removed in TYPO3 4.6
+* This file is now located at typo3/js/jsfunc.md5.js
+****************************************************************/
+
/*
* md5.jvs 1.0b 27/06/96
*
Index: typo3/mod/web/perm/index.php
===================================================================
--- typo3/mod/web/perm/index.php (revision 6707)
+++ typo3/mod/web/perm/index.php (working copy)
@@ -214,7 +214,7 @@
$this->doc->backPath = $GLOBALS['BACK_PATH'];
$this->doc->setModuleTemplate('templates/perm.html');
$this->doc->form = '';
if ($GLOBALS['BE_USER']->uc['TSFE_adminConfig']['display_top']) {
- $out .= '';
+ $out .= '';
$out .= '
';
+ $GLOBALS['TSFE']->additionalHeaderData['JSFormValidate'] = '';
} else $validateForm='';
// Create form tag:
@@ -6976,7 +6976,7 @@
}
/**
- * Returns a JavaScript
';
- $GLOBALS['TSFE']->additionalHeaderData['JSincludeFormupdate']='';
+ $GLOBALS['TSFE']->additionalHeaderData['JSincludeFormupdate']='';
return $JSPart;
}
Index: typo3/sysext/cms/tslib/class.tslib_fe.php
===================================================================
--- typo3/sysext/cms/tslib/class.tslib_fe.php (revision 6707)
+++ typo3/sysext/cms/tslib/class.tslib_fe.php (working copy)
@@ -272,8 +272,8 @@
/*
Eg. insert JS-functions in this array ($additionalHeaderData) to include them once. Use associative keys.
Keys in use:
- JSFormValidate :
- JSincludeFormupdate :
+ JSFormValidate :
+ JSincludeFormupdate :
JSMenuCode, JSMenuCode_menu : JavaScript for the JavaScript menu
JSCode : reserved
JSImgCode : reserved
Index: typo3/sysext/cms/tslib/class.tslib_menu.php
===================================================================
--- typo3/sysext/cms/tslib/class.tslib_menu.php (revision 6707)
+++ typo3/sysext/cms/tslib/class.tslib_menu.php (working copy)
@@ -2832,7 +2832,7 @@
}
$JScode.= $this->generate_level($levels,1,$this->id,$this->menuArr,$this->MP_array)."\n";
- $GLOBALS['TSFE']->additionalHeaderData['JSMenuCode']='';
+ $GLOBALS['TSFE']->additionalHeaderData['JSMenuCode']='';
$GLOBALS['TSFE']->JSCode.=$JScode;
// Printing:
Index: typo3/sysext/rtehtmlarea/mod3/class.tx_rtehtmlarea_browse_links.php
===================================================================
--- typo3/sysext/rtehtmlarea/mod3/class.tx_rtehtmlarea_browse_links.php (revision 6707)
+++ typo3/sysext/rtehtmlarea/mod3/class.tx_rtehtmlarea_browse_links.php (working copy)
@@ -230,7 +230,7 @@
$this->doc->backPath = $GLOBALS['BACK_PATH'];
// Loading the Prototype library and browse_links.js
$this->doc->getPageRenderer()->loadPrototype();
- $this->doc->loadJavascriptLib('js/browse_links.js');
+ $this->doc->loadJavascriptLib('js/jsfunc.browse_links.js');
// Adding context menu code
$this->doc->getContextMenuCode();
// Init fileProcessor
Index: typo3/sysext/rtehtmlarea/mod4/class.tx_rtehtmlarea_select_image.php
===================================================================
--- typo3/sysext/rtehtmlarea/mod4/class.tx_rtehtmlarea_select_image.php (revision 6707)
+++ typo3/sysext/rtehtmlarea/mod4/class.tx_rtehtmlarea_select_image.php (working copy)
@@ -181,7 +181,7 @@
// Load the Prototype library and browse_links.js
$this->doc->getPageRenderer()->loadPrototype();
- $this->doc->loadJavascriptLib('js/browse_links.js');
+ $this->doc->loadJavascriptLib('js/jsfunc.browse_links.js');
$this->doc->getContextMenuCode();
}
Index: typo3/sysext/setup/mod/index.php
===================================================================
--- typo3/sysext/setup/mod/index.php (revision 6707)
+++ typo3/sysext/setup/mod/index.php (working copy)
@@ -313,7 +313,7 @@
}
// Start page:
- $this->doc->loadJavascriptLib('md5.js');
+ $this->doc->loadJavascriptLib('js/jsfunc.md5.js');
// use a wrapper div
$this->content .= '';
Index: typo3/sysext/sv/class.tx_sv_loginformhook.php
===================================================================
--- typo3/sysext/sv/class.tx_sv_loginformhook.php (revision 6707)
+++ typo3/sysext/sv/class.tx_sv_loginformhook.php (working copy)
@@ -82,7 +82,7 @@
if ($pObj->loginSecurityLevel == 'superchallenged' ||
$pObj->loginSecurityLevel == 'challenged') {
$content = '
-
+
' . $GLOBALS['TBE_TEMPLATE']->wrapScriptTags('
function doChallengeResponse(superchallenged) { //
password = document.loginform.p_field.value;
Index: typo3/tab.js
===================================================================
--- typo3/tab.js (revision 6707)
+++ typo3/tab.js (working copy)
@@ -1,3 +1,9 @@
+/***************************************************************
+* ! DEPRECATED !
+* This file will be removed in TYPO3 4.6
+* This file is now located at typo3/js/jsfunc.tab.js
+****************************************************************/
+
/*
* This code has been copied from Project_CMS
* Copyright (c) 2005 by Phillip Berndt (www.pberndt.com)
Index: typo3/sysext/fluid/Classes/ViewHelpers/Be/ContainerViewHelper.php
===================================================================
--- typo3/sysext/fluid/Classes/ViewHelpers/Be/ContainerViewHelper.php (revision 6707)
+++ typo3/sysext/fluid/Classes/ViewHelpers/Be/ContainerViewHelper.php (working copy)
@@ -55,7 +55,7 @@
*
* @param string $pageTitle title tag of the module. Not required by default, as BE modules are shown in a frame
* @param boolean $enableJumpToUrl If TRUE, includes "jumpTpUrl" javascript function required by ActionMenu. Defaults to TRUE
* @param boolean $enableClickMenu If TRUE, loads clickmenu.js required by BE context menus. Defaults to TRUE
* @param boolean $loadPrototype specifies whether to load prototype library. Defaults to TRUE
* @param boolean $loadScriptaculous specifies whether to load scriptaculous libraries. Defaults to FALSE
* @param string $scriptaculousModule additionales modules for scriptaculous
@@ -85,7 +85,7 @@
';
}
if ($enableClickMenu) {
- $doc->loadJavascriptLib('js/clickmenu.js');
+ $doc->loadJavascriptLib('js/jsfunc.clickmenu.js');
}
if ($loadPrototype) {
$pageRenderer->loadPrototype();
@@ -55,7 +55,7 @@
* @param string $pageTitle title tag of the module. Not required by default, as BE modules are shown in a frame
* @param boolean $enableJumpToUrl If TRUE, includes "jumpTpUrl" javascript function required by ActionMenu. Defaults to TRUE
- * @param boolean $enableClickMenu If TRUE, loads clickmenu.js required by BE context menus. Defaults to TRUE
+ * @param boolean $enableClickMenu If TRUE, loads jsfunc.clickmenu.js required by BE context menus. Defaults to TRUE
* @param boolean $loadPrototype specifies whether to load prototype library. Defaults to TRUE
* @param boolean $loadScriptaculous specifies whether to load scriptaculous libraries. Defaults to FALSE
Index: typo3/template.php
===================================================================
--- typo3/template.php (revision 6707)
+++ typo3/template.php (working copy)
@@ -692,7 +692,7 @@
// This loads the tabulator-in-textarea feature. It automatically modifies
// every textarea which is found.
if (!$GLOBALS['BE_USER']->uc['disableTabInTextarea']) {
- $this->loadJavascriptLib('tab.js');
+ $this->loadJavascriptLib('js/jsfunc.tab.js');
}
// Get the browser info
@@ -1365,7 +1365,7 @@
*/
function getContextMenuCode() {
$this->pageRenderer->loadPrototype();
- $this->loadJavascriptLib('js/clickmenu.js');
+ $this->loadJavascriptLib('js/jsfunc.clickmenu.js');
$this->JScodeArray['clickmenu'] = '
Clickmenu.clickURL = "'.$this->backPath.'alt_clickmenu.php";
@@ -1376,7 +1376,7 @@
}
/**
* Includes the necessary javascript file (tree.js) for use on pages which have the
* drag and drop functionality (usually pages and folder display trees)
*
* @param string indicator of which table the drag and drop function should work on (pages or folders)
@@ -1384,8 +1384,8 @@
*/
function getDragDropCode($table) {
$this->pageRenderer->loadPrototype();
- $this->loadJavascriptLib('js/common.js');
- $this->loadJavascriptLib('js/tree.js');
+ $this->loadJavascriptLib('js/jsfunc.common.js');
+ $this->loadJavascriptLib('js/jsfunc.tree.js');
// setting prefs for drag & drop
$this->JScodeArray['dragdrop'] = '
@@ -1516,7 +1516,7 @@
*/
function getDynTabMenu($menuItems,$identString,$toggle=0,$foldout=FALSE,$newRowCharLimit=50,$noWrap=1,$fullWidth=FALSE,$defaultTabIndex=1,$dividers2tabs=2) {
// load the static code, if not already done with the function below
- $this->loadJavascriptLib('js/tabmenu.js');
+ $this->loadJavascriptLib('js/jsfunc.tabmenu.js');
$content = '';
@@ -1664,7 +1664,7 @@
* @return string JavaScript section for the HTML header. (return value is deprecated since TYPO3 4.3, will be removed in TYPO3 4.5)
*/
function getDynTabMenuJScode() {
- $this->loadJavascriptLib('js/tabmenu.js');
+ $this->loadJavascriptLib('js/jsfunc.tabmenu.js');
// return value deprecated since TYPO3 4.3
return '';
}
@@ -1857,7 +1857,7 @@
function setModuleTemplate($filename) {
// Load Prototype lib for IE event
$this->pageRenderer->loadPrototype();
- $this->loadJavascriptLib('js/iecompatibility.js');
+ $this->loadJavascriptLib('js/jsfunc.iecompatibility.js');
$this->moduleTemplate = $this->getHtmlTemplate($filename);
}
@@ -1376,7 +1376,7 @@
}
/**
- * Includes the necessary javascript file (tree.js) for use on pages which have the
+ * Includes the necessary javascript file (jsfunc.tree.js) for use on pages which have the
* drag and drop functionality (usually pages and folder display trees)
*